@@ -48,10 +48,14 @@ func (n *Namespace) Validate(c client.Connection, ks KubeSettings) {
 
 // SetActive set the active namespace.
 func (n *Namespace) SetActive(ns string, ks KubeSettings) error {
+	if ns == client.NotNamespaced {
+		ns = client.AllNamespaces
+	}
 	n.Active = ns
 	if ns != "" && !n.LockFavorites {
 		n.addFavNS(ns)
 	}
+
 	return nil
 }
 
